@@ -23,6 +23,8 @@
 
 #include <X11/ICE/ICElib.h>
 #include <X11/ICE/ICEutil.h>
+
+#include <glib/gi18n.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
@@ -38,7 +40,6 @@
 #endif
 
 #include <libgnomeui/gnome-ice.h>
-#include <libgnome/libgnome.h>
 #include <gconf/gconf-client.h>
 
 #include "ice.h"
@@ -315,7 +316,6 @@ void
 initialize_ice (void)
 {
   char error[256];
-  char *p;
   guint i;
   GSList* entries;
   int saved_umask;
@@ -382,9 +382,8 @@ initialize_ice (void)
   auth_entries = entries;
 
   ids = IceComposeNetworkIdList (num_sockets, sockets);
-
-  p = g_strconcat (ENVNAME "=", ids, NULL);
-  putenv (p);
+  g_setenv (ENVNAME, ids, TRUE);
+  free (ids);
   
   ice_depth = 0;	/* We are live */
 }
@@ -456,9 +455,14 @@ clean_ice (void)
   /* During shutdown we don't want to report errors via a dialog.  */
   write_authfile (authfile, entries, FALSE);
 
+  g_slist_foreach (entries, (GFunc)IceFreeAuthFileEntry, NULL);
+  g_slist_free (entries);
+
   g_free (input_id);
-  free (ids);
   IceFreeListenObjs (num_sockets, sockets);
+
+  g_slist_foreach (auth_entries, (GFunc)IceFreeAuthFileEntry, NULL);
+  g_slist_free (auth_entries);
   
   ice_depth = ~0;	/* We are very frozen, like totally off */
 }
